camelot.camelot.view.model_thread.ModelThreadException

Package camelot :: Package camelot :: Package view :: Module model_thread :: Class ModelThreadException |
[hide private]
[frames] | no frames]

# Class ModelThreadException

source code

Instance Methods | [hide private]
Inherited from `exceptions.Exception`: `__init__`, `__new__` Inherited from `exceptions.BaseException`: `__delattr__`, `__getattribute__`, `__getitem__`, `__getslice__`, `__reduce__`, `__repr__`, `__setattr__`, `__setstate__`, `__str__` Inherited from `object`: `__hash__`, `__reduce_ex__`

Properties | [hide private]
Inherited from `exceptions.BaseException`: `args`, `message` Inherited from `object`: `__class__`